machado’s documentation — machado 0.1.0 documentation

# machado’s documentation

machado provides users with a framework to store, search and visualize biological data.

It is a framework powered by Django that contains tools to interact with a Chado.

# Content

- 1. Installation
- 2. Data loading
  - 2.1. Ontologies
  - 2.2. Taxonomy
  - 2.3. Organism
  - 2.4. Publication
  - 2.5. FASTA
  - 2.6. GFF
  - 2.7. Feature additional info
  - 2.8. Blast
  - 2.9. InterproScan
  - 2.10. OrthoMCL
  - 2.11. RNA-seq
  - 2.12. Coexpression
- 3. Visualization
  - 3.1. Index and search
  - 3.2. Web server
  - 3.3. JBrowse
  - 3.4. Cache
- 4. Diagrams
- 5. Models

- Search Page